// =======================================================================================
//
//  orbit.cpp
//
//  Screen Saver Module for BeOS
//
// =======================================================================================

#include <stdio.h>
#include "orbit.h"

const float MINX = -90.0f;
const float MAXX = 90.0f;
const float MINY = -70.0f;
const float MAXY = 70.0f;
const float light_pos[4] = { 0.0f, 0.0f, 0.0f, 1.0f };

void Normalize(float *pVec);

// ---------------------------------------------------------------------------------------
//  Global saver functions
// ---------------------------------------------------------------------------------------

BScreenSaver *instantiate_screen_saver(BMessage *pMsg, image_id img)
{
	return new COrbitSaver(pMsg, img);
}

// ---------------------------------------------------------------------------------------
//  COrbitSaver Member Functions
// ---------------------------------------------------------------------------------------

COrbitSaver::COrbitSaver(BMessage *pMsg, image_id img)
	: BScreenSaver(pMsg, img)
{
	bConfigOK = true;
	pGLView = 0;

	if(pMsg->FindInt8("PlanetSize", &settings.nPlanetSize) != B_OK)
		settings.nPlanetSize = 12;

	if(pMsg->FindFloat("Alpha", &settings.fPlanetAlpha) != B_OK)
		settings.fPlanetAlpha = 0.3f;

	if(pMsg->FindInt8("MotionType", &settings.nMotionType) != B_OK)
		settings.nMotionType = MOTION_BOUNCE;


	if(pMsg->FindInt8("SatSize", &settings.nSatSize) != B_OK)
		settings.nSatSize = 4;

	if(pMsg->FindInt8("Satellites", &settings.nSatellites) != B_OK)
		settings.nSatellites = 3;

	if(pMsg->FindInt8("OrbitType", &settings.nOrbitType) != B_OK)
		settings.nOrbitType = MOTION_SPHERICAL;


	if(pMsg->FindBool("Fog", &settings.bFog) != B_OK)
		settings.bFog = false;

	if(pMsg->FindBool("Background", &settings.bBackground) != B_OK)
		settings.bBackground = false;

/*
	char outp[512];
	sprintf(outp,
		"COrbitSaver constructor:\n"
		"PlanetSize: %d\n"
		"Alpha:      %f\n"
		"MotionType: %d\n"
		"SatSize:    %d\n"
		"Satellites: %d\n"
		"OrbitType:  %d\n"
		"Fog:        %d\n"
		"Background: %d\n",
		settings.nPlanetSize,
		settings.fPlanetAlpha,
		settings.nMotionType,
		settings.nSatSize,
		settings.nSatellites,
		settings.nOrbitType,
		settings.bFog,
		settings.bBackground);

	debugger(outp);
*/			
	SetTickSize(10000);
}

// ---------------------------------------------------------------------------------------

status_t COrbitSaver::InitCheck()
{
	return (bConfigOK ? B_OK : B_ERROR);
}

// ---------------------------------------------------------------------------------------

status_t COrbitSaver::SaveState(BMessage *pMsg) const
{
	pMsg->AddInt8(  "PlanetSize", settings.nPlanetSize);
	pMsg->AddFloat( "Alpha",      settings.fPlanetAlpha);
	pMsg->AddInt8(  "MotionType", settings.nMotionType);
	pMsg->AddInt8(  "SatSize",    settings.nSatSize);
	pMsg->AddInt8(  "Satellites", settings.nSatellites);
	pMsg->AddInt8(  "OrbitType",  settings.nOrbitType);
	pMsg->AddBool(  "Fog",        settings.bFog);
	pMsg->AddBool(  "Background", settings.bBackground);

	return B_OK;
}

// ---------------------------------------------------------------------------------------

void COrbitSaver::StartConfig(BView *pView)
{
	pView->AddChild(new COrbitConfig(pView->Bounds(), &settings));
}

// ---------------------------------------------------------------------------------------

status_t COrbitSaver::StartSaver(BView *pView, bool bPreview)
{
	if(bPreview) return B_ERROR; // since we're strictly DirectDraw, no preview

	pGLView = new COrbitView(
		pView->Bounds(), "OrbitView", B_FOLLOW_NONE,
		BGL_RGB|BGL_ALPHA|BGL_DEPTH|BGL_DOUBLE, &settings);
		
	if(!pGLView) return B_ERROR; // yikes!

	pView->AddChild(pGLView);

	return B_OK;
}

// ---------------------------------------------------------------------------------------

void COrbitSaver::StopSaver()
{
	if(pGLView)
		pGLView->EnableDirectMode(false);
}

// ---------------------------------------------------------------------------------------

void COrbitSaver::DirectConnected(direct_buffer_info *pInf)
{
	pGLView->DirectConnected(pInf);
	pGLView->EnableDirectMode(true);
}

// ---------------------------------------------------------------------------------------

void COrbitSaver::DirectDraw(int32 nFrame)
{
	pGLView->DrawFrame();
}

