// =======================================================================================
//
//  orbitconfig.h
//
//  Screen Saver Module for BeOS - configuration class
//
// =======================================================================================

#ifndef _ORBITCONFIG_H_
#define _ORBITCONFIG_H_

#include <Slider.h>
#include <CheckBox.h>
#include <RadioButton.h>

// ---------------------------------------------------------------------------------------

const char APPNAME[] = "Orbit v1.1";

// planet motions
const int8 MOTION_BOUNCE = 0;
const int8 MOTION_ORBIT  = 1;

// satellite motions
const int8 MOTION_SPHERICAL = 2;
const int8 MOTION_PLANAR    = 3;

// ---------------------------------------------------------------------------------------

struct OrbitSettings {
	// planet settings
	int8     nPlanetSize;
	float    fPlanetAlpha;
	int8     nMotionType;

	// satellite settings
	int8     nSatellites;
	int8     nSatSize;
	int8     nOrbitType;

	// miscellaneous settings
	bool     bFog;
	bool     bBackground;
};

// ---------------------------------------------------------------------------------------

class COrbitConfig : public BView
{
private:
	BSlider       *pCtlPSize; // planet size control
	BSlider       *pCtlAlpha; // planet alpha control
	BSlider       *pCtlSSize; // satellite size control
	BSlider       *pCtlSNum;  // satellite number control

	BRadioButton  *pCtlMot0;  // planet motion type 0
	BRadioButton  *pCtlMot1;  // planet motion type 1

	BRadioButton  *pCtlOrb0;  // satellite orbit type 0
	BRadioButton  *pCtlOrb1;  // satellite orbit type 1

	BCheckBox     *pCtlBG;    // enable background control
	BCheckBox     *pCtlFog;   // enable fog control

	OrbitSettings *pSettings;

	unsigned int  nWindowFlags;

public:
	COrbitConfig(BRect rect, OrbitSettings *pSetIn);

	virtual void AttachedToWindow();
	virtual void DetachedFromWindow();
	virtual void MessageReceived(BMessage *pMsg);
};

// ---------------------------------------------------------------------------------------

#endif // _ORBITCONFIG_H_
